@@ -1,8 +1,12 @@
 from __future__ import annotations
 
+import pickle
 from pathlib import Path
+from typing import Optional
 
-from ufoLib2.objects import Font, Glyph, Guideline
+import pytest
+
+from ufoLib2.objects import Font, Glyph, Guideline, Layer
 
 
 def test_font_equality(datadir: Path) -> None:
@@ -101,3 +105,57 @@ def test_data_images_init() -> None:
     assert font.data["bbb/c"] == b"456"
     assert font.images["a.png"] == b"\x89PNG\r\n\x1a\n"
     assert font.images["b.png"] == b"\x89PNG\r\n\x1a\n"
+
+
+@pytest.mark.parametrize(
+    "lazy", [None, False, True], ids=["lazy-unset", "non-lazy", "lazy"]
+)
+def test_pickle_lazy_font(datadir: Path, lazy: Optional[bool]) -> None:
+    if lazy is not None:
+        font = Font.open(datadir / "UbuTestData.ufo", lazy=lazy)
+    else:
+        # lazy is None by default for a Font that is not opened from a file
+        # but created from scratch
+        font = Font()
+
+    assert lazy is font._lazy
+
+    data = pickle.dumps(font)
+
+    assert isinstance(data, bytes) and len(data) > 0
+
+    # picklying unlazifies
+    if lazy:
+        assert font._lazy is False
+    else:
+        assert font._lazy is lazy
+
+    font2 = pickle.loads(data)
+
+    assert isinstance(font2, Font)
+    assert font == font2
+    # unpickling doesn't initialize the lazy flag or a reader, which reset to default
+    assert font2._lazy is None
+    assert font2._reader is None
+
+
+def test_tempLib_not_saved(tmp_path: Path) -> None:
+    font = Font(
+        layers=[
+            Layer(
+                glyphs=[Glyph("a", tempLib={"something": 123})],
+                tempLib={"hello": b"world"},
+            )
+        ],
+        tempLib={"foo": {"bar": b"baz"}},
+    )
+    assert font.tempLib
+    assert font.layers.defaultLayer.tempLib
+    assert font["a"].tempLib
+
+    font.save(tmp_path / "Font.ufo")
+
+    font2 = Font.open(tmp_path / "Font.ufo")
+    assert not font2.tempLib
+    assert not font2.layers.defaultLayer.tempLib
+    assert not font2["a"].tempLib
